==> nextcloud-30.0.5.tgz: nextcloud/apps/circles/l10n/is.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Þú eyddir {circle}",
    "{author} deleted {circle}" : "{author} eyddi {circle}",
    "You removed {member} from {circle}" : "Þú fjarlægðir {member} úr {circle}",
    "You joined {circle}" : "Þú gekkst í {circle}",
    "{member} joined {circle}" : "{member} gekk í {circle}",
    "You accepted the invitation to join {circle}" : "Þú samþykktir boð um að taka þátt í {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} samþykkti boð um að taka þátt í {circle}",
    "You added {member} as member to {circle}" : "Þú bættir {member} sem meðlim í {circle}",
    "You have been added as member to {circle} by {author}" : "Þér var bætt við sem meðlimi í {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} var bætt við sem meðlimi í {circle} af {author}",
    "You added {external} to {circle}" : "Þú bættir {external} í {circle}",
    "{external} has been added to {circle} by {author}" : "{external} var bætt við í {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Þú samþykktir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Beiðni þín um að ganga í {circle} var samþykkt af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Beiðni frá {member} um að ganga í {circle} var samþykkt af {author}",
    "You left {circle}" : "Þú gekkst úr {circle}",
    "{member} left {circle}" : "{member} gekk úr {circle}",
    "You declined the invitation to join {circle}" : "Þú hafnaðir boðinu um að taka þátt í {circle}",
    "{member} declined an invitation to join {circle}" : "{member} hafnaði boði um að taka þátt í {circle}",
    "You cancelled your request to join {circle}" : "Þú hættir við beiðni þína um að taka þátt í {circle}",
    "You have been removed from {circle} by {author}" : "Þú varst fjarlægður úr {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} var fjarlægður úr {circle} af {author}",
    "You removed {external} from {circle}" : "Þú fjarlægðir {external} úr {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} var fjarlægður úr {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Þú dróst til baka beiðni frá {member} um að taka þátt í {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Beiðni þín um að ganga í {circle} var dregin til baka af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} dró til baka boð til {member} um að taka þátt í {circle}",
    "You dismissed {member}'s request to join {circle}" : "Þú hunsaðir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Beiðni þín um að ganga í {circle} var hunsuð af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Beiðni frá {member} um að ganga í {circle} var hunsuð af {author}",
    "You invited {member} to join {circle}" : "Þú bauðst {member} að taka þátt í {circle}",
    "You have been invited to join {circle} by {author}" : "Þér hefur verið boðið að ganga í {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} hefur verið boðið að ganga í {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Þú breyttir stigi {member} í {circle} yfir í %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} breytti stigi þínu í {circle} yfir í %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} breytti stigi {member} í {circle} yfir í %1$s",
    "You sent a request to join {circle}" : "Þú sendir beiðni um að taka þátt í {circle}",
    "{member} sent a request to join {circle}" : "{member} sendi beiðni um að taka þátt í {circle}",
    "You are the new owner of {circle}" : "Þú ert nýr eigandi {circle}",
    "{member} is the new owner of {circle}" : "{member} er nýr eigandi {circle}",
    "Shared to Circles" : "Deilt til hringja",
    "Single" : "Stakur",
    "Personal" : "Persónulegur",
    "System" : "Kerfið",
    "Visible" : "Sýnilegt",
    "Open" : "Opna",
    "Invite" : "Bjóða",
    "Friends" : "Vinir",
    "Password protected" : "Verja með lykilorði",
    "No Owner" : "Enginn eigandi",
    "Hidden" : "Falinn",
    "Backend" : "Bakendi",
    "Local" : "Staðvært",
    "Root" : "Rót (root)",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Mount point" : "Tengipunktur",
    "Nextcloud Account" : "Nextcloud-aðgangur",
    "Nextcloud Group" : "Nextcloud-hópur",
    "Email address" : "Tölvupóstfang",
    "Contact" : "Tengiliður",
    "Circle" : "Hringur",
    "Nextcloud App" : "Nextcloud-forrit",
    "Member" : "Meðlimur",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnandi",
    "Owner" : "Eigandi",
    "%s shared »%s« with you." : "%s deildi »%s« með þér.",
    "%s shared »%s« with \"%s\"." : "%s deildi »%s« með \"%s\".",
    "%s on %s" : "%s á %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s deildi »%2$s« með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s deildi »%2$s« með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s via %2$s" : "%1$s með %2$s",
    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s deildi mörgum skrám með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s deildi mörgum skrám með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access files shared to you by %1$s" : "Lykilorði fyrir aðgang að skránum var deilt með þér af %$s",
    "Password to access files" : "Lykilorð fyrir aðgang að skrám",
    "%s shared multiple files with \"%s\"." : "%s deildi mörgum skrám með \"%s\".",
    "%s shared multiple files with you." : "%s deildi mörgum skrám með þér.",
    "Boot up" : "Ræsing",
    "Nextcloud Initialization" : "Frumstilling Nextcloud",
    "Circles App Initialization" : "Frumstilling Circles forrits",
    "Fresh installation status" : "Staða ferskrar uppsetningar",
    "Building Local Database" : "Byggi staðværan gagnagrunn",
    "Testing Basic Circle Creation" : "Prófa einfalda gerð hrings",
    "Adding local users and moderators" : "Bæti við notendum og umsjónarmönnum",
    "Files" : "Skráaforrit",
    "This feature is not available for personal circles" : "Þessi eiginleiki er ekki tiltækur fyrir persónulega hringi",
    "This member is not a moderator" : "Þessi meðlimur er ekki umsjónarmaður",
    "Insufficient privileges" : "Ekki næg réttindi",
    "This member does not exist" : "Þessi meðlimur er ekki til",
    "Level cannot be changed for this type of member" : "Ekki er hægt að breyta stigi fyrir þessa gerð meðlims",
    "You are already a member of this circle" : "Þú ert nú þegar meðlimur í þessum hring",
    "You have been blocked from this circle" : "Þú hefur verið útilokaður frá þessum hring",
    "The account is already a member of this circle" : "Notandaaðgangurinn er nú þegar meðlimur í þessum hring",
    "The account has already been invited into this circle" : "Notandaaðgangnum hefur þegar verið boðið að taka þátt í þessum hring",
    "Accept" : "Samþykkja",
    "Refuse" : "Neita",
    "%s" : "%s",
    "%s owned by %s" : "%s í eigu notandans %s",
    "%s shared a file with \"%s\"." : "%s deildi skrá með \"%s\".",
    "%s shared a file with you." : "%s deildi skrá með þér",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s deildi einhverju efni með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s deildi einhverju efni með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "Password to access content shared with you by %1$s" : "Lykilorði fyrir aðgang að efni var deilt með þér af %1$s",
    "Password to access content" : "Lykilorð fyrir aðgang að efni",
    "Bring cloud-users closer together." : "Færir notendur tölvuskýja nær hver öðrum.",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar færslur fundust í þessari möppu",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "Circles" : "Hringir",
    "Circles' files" : "Skrár í hringjum",
    "Select circles to filter by" : "Veldu hringi til að sía eftir",
    "No circles found" : "Engir hringir fundust",
    "Please select circles to filter by" : "Veldu hringi til að sía eftir",
    "No files found for the selected circles" : "Engar skrár fundust með völdum hringjum",
    "You created the circle {circle}" : "Þú bjóst til hringinn {circle}",
    "{author} created the circle {circle}" : "{author} bjó til hringinn {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Við atburði sem gerast í <strong>hring</strong> sem þú tilheyrir",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Hvaða mikilvægi atburður sem er í <strong>hring</strong> sem þú hefur umsjón með",
    "On global events happening in any <strong>Circle</strong>" : "Við almenna atburði sem gerast í hvaða <strong>hring</strong> sem er",
    "Join Request" : "Beiðni um þátttöku",
    "Password Protected" : "Verndað með aðgangsorði",
    "Circle Invite" : "Boð í hring",
    "Email Address" : "Tölvupóstfang",
    "Circle not found" : "Hringur fannst ekki",
    "Circle not found " : "Hringur fannst ekki ",
    "This account is already a member of the circle" : "Þessi notandaaðgangur er nú þegar meðlimur í hringnum",
    "Federated link not found" : "Skyjasambandstengill fannst ekki",
    "The circle is not federated" : "Hringurinn er ekki í skýjasambandi",
    "You cannot join this circle" : "Þú getur ekki tekið þátt í þessum hring",
    "This member is the owner of the circle" : "Þessi meðlimur er eigandi hringsins",
    "%s (Circle owned by %s)" : "%s (Hringur í eigu notandans %s)",
    "You are now a member of the Circle \"%2$s\"" : "Þú ert núna meðlimur í hringnum \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s bauð þér að ganga í hringinn \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendi beiðni um að taka þátt í hringnum \"%2$s\"",
    "Leave the circle" : "Ganga úr þessum hring",
    "Personal Circle" : "Persónulegur hringur",
    "You need a specify a type of circle" : "Þú verður að tiltaka gerð hrings",
    "A circle with that name exists" : "Nú þegar er til hringur með þetta nafn",
    "This member is not the owner of the circle" : "Þessi meðlimur er ekki eigandi hringsins",
    "This member is not an admin of the circle" : "Þessi meðlimur er ekki stjórnandi hringsins",
    "Group contains too many members" : "Hópur inniheldur of marga meðlimi",
    "This group does not exist" : "Þessi hópur er ekki til",
    "This group is already linked to the circle" : "Þessi hópur er nú þegar tengdur hringnum",
    "You cannot edit level in a personal circle" : "Þú getur ekki breytt stigum í persónulegum hring",
    "Group cannot be set as owner of a circle" : "Hópur getur ekki verið eigandi á hring",
    "now" : "núna",
    "This account does not exist" : "Þessi notandaaðgangur er ekki til",
    "Email format is not valid" : "Snið póstfangsins er ekki gilt",
    "This contact is not available" : "Þessi tengiliður er ekki tiltækur",
    "You have no permission to create a new circle" : "Þú hefur ekki leyfi til að búa til nýjan hring",
    "This item is already shared with this circle" : "Þessu atriði er þegar deilt með þessum hring",
    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Hringir/Circles gerir fólki kleift að búa til sína eigin hópa af fólki/samstarfsaðilum/vinum.\nÞessa hópa (eða \"hringi\") má síðan nota í deilingaskyni af allskyns öðrum forritum."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-30.0.12.tgz: nextcloud/apps/circles/l10n/is.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Teymi",
    "You created the team {circle}" : "Þú bjóst til teymið {circle}",
    "{author} created the team {circle}" : "{author} bjó til teymið {circle}",
    "You deleted {circle}" : "Þú eyddir {circle}",
    "{author} deleted {circle}" : "{author} eyddi {circle}",
    "You made {member} join {circle}" : "Þú lést {member} taka þátt í {circle}",
    "{author} made {member} join {circle}" : "{author} lét {member} taka þátt í {circle}",
    "You added team {member} as member to {circle}" : "Þú bættir teyminu {member} við sem meðlimi í {circle}",
    "{author} added team {member} as member to {circle}" : "{author} bætti teyminu {member} við sem meðlimi í {circle}",
    "You made {member} leave {circle}" : "Þú lést {member} yfirgefa {circle}",
    "{author} made {member} leave {circle}" : "{author} lét {member} yfirgefa {circle}",
    "You removed {member} from {circle}" : "Þú fjarlægðir {member} úr {circle}",
    "{author} removed {member} from {circle}" : "{author} fjarlægði {member} úr {circle}",
    "You joined {circle}" : "Þú gekkst í {circle}",
    "{member} joined {circle}" : "{member} gekk í {circle}",
    "You accepted the invitation to join {circle}" : "Þú samþykktir boð um að taka þátt í {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} samþykkti boð um að taka þátt í {circle}",
    "You added {member} as member to {circle}" : "Þú bættir {member} sem meðlim í {circle}",
    "You have been added as member to {circle} by {author}" : "Þér var bætt við sem meðlimi í {circle} af {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} var bætt við sem meðlimi í {circle} af {author}",
    "You added {external} to {circle}" : "Þú bættir {external} í {circle}",
    "{external} has been added to {circle} by {author}" : "{external} var bætt við í {circle} af {author}",
    "You accepted {member}'s request to join {circle}" : "Þú samþykktir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Beiðni þín um að ganga í {circle} var samþykkt af {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Beiðni frá {member} um að ganga í {circle} var samþykkt af {author}",
    "You left {circle}" : "Þú gekkst úr {circle}",
    "{member} left {circle}" : "{member} gekk úr {circle}",
    "You declined the invitation to join {circle}" : "Þú hafnaðir boðinu um að taka þátt í {circle}",
    "{member} declined an invitation to join {circle}" : "{member} hafnaði boði um að taka þátt í {circle}",
    "You cancelled your request to join {circle}" : "Þú hættir við beiðni þína um að taka þátt í {circle}",
    "{member} cancelled a request to join {circle}" : "{member} hætti við beiðni um að taka þátt í {circle}",
    "You have been removed from {circle} by {author}" : "Þú varst fjarlægður úr {circle} af {author}",
    "{member} has been removed from {circle} by {author}" : "{member} var fjarlægður úr {circle} af {author}",
    "You removed {external} from {circle}" : "Þú fjarlægðir {external} úr {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} var fjarlægður úr {circle} af {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Þú dróst til baka beiðni frá {member} um að taka þátt í {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Beiðni þín um að ganga í {circle} var dregin til baka af {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} dró til baka boð til {member} um að taka þátt í {circle}",
    "You dismissed {member}'s request to join {circle}" : "Þú hunsaðir beiðni frá {member} um að taka þátt í {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Beiðni þín um að ganga í {circle} var hunsuð af {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Beiðni frá {member} um að ganga í {circle} var hunsuð af {author}",
    "You invited {member} to join {circle}" : "Þú bauðst {member} að taka þátt í {circle}",
    "You have been invited to join {circle} by {author}" : "Þér hefur verið boðið að ganga í {circle} af {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} hefur verið boðið að ganga í {circle} af {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Þú breyttir stigi {member} í {circle} yfir í %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} breytti stigi þínu í {circle} yfir í %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} breytti stigi {member} í {circle} yfir í %1$s",
    "You sent a request to join {circle}" : "Þú sendir beiðni um að taka þátt í {circle}",
    "{member} sent a request to join {circle}" : "{member} sendi beiðni um að taka þátt í {circle}",
    "You are the new owner of {circle}" : "Þú ert nýr eigandi {circle}",
    "{member} is the new owner of {circle}" : "{member} er nýr eigandi {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Við atburði sem gerast í <strong>teymi</strong> sem þú tilheyrir",
    "Any important event in a <strong>team</strong> you are moderating" : "Hvaða mikilvægi atburður sem er í <strong>teymi</strong> sem þú hefur umsjón með",
    "On global events happening in any <strong>team</strong>" : "Við almenna atburði sem gerast í hvaða <strong>teymi</strong> sem er",
    "Single" : "Stakur",
    "Personal" : "Persónulegur",
    "System" : "Kerfið",
    "Visible" : "Sýnilegt",
    "Open" : "Opna",
    "Invite" : "Bjóða",
    "Join request" : "Beiðni um þátttöku",
    "Friends" : "Vinir",
    "Password protected" : "Verja með lykilorði",
    "No Owner" : "Enginn eigandi",
    "Hidden" : "Falinn",
    "Backend" : "Bakendi",
    "Local" : "Staðvært",
    "Root" : "Rót (root)",
    "Team invite" : "Boð í teymi",
    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
    "Mount point" : "Tengipunktur",
    "Nextcloud Account" : "Nextcloud-aðgangur",
    "Nextcloud Group" : "Nextcloud-hópur",
    "Email address" : "Tölvupóstfang",
    "Contact" : "Tengiliður",
    "Circle" : "Hringur",
    "Nextcloud App" : "Nextcloud-forrit",
    "Member" : "Meðlimur",
    "Moderator" : "Umsjónarmaður",
    "Admin" : "Stjórnandi",
    "Owner" : "Eigandi",
    "%s shared »%s« with you." : "%s deildi »%s« með þér.",
    "%s shared »%s« with \"%s\"." : "%s deildi »%s« með \"%s\".",
    "%s on %s" : "%s á %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s deildi »%2$s« með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s deildi »%2$s« með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access »%1$s« shared to you by %2$s" : "Lykilorði fyrir aðgang að »%1$s« var deilt með þér af %2$s",
    "Password to access »%s«" : "Lykilorð fyrir aðgang að »%s«",
    "It is protected with the following password:" : "Það er varið með eftirfarandi lykilorði:",
    "%1$s via %2$s" : "%1$s með %2$s",
    "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
    "Open »%s«" : "Opna »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s deildi mörgum skrám með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s deildi mörgum skrám með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.",
    "Password to access files shared to you by %1$s" : "Lykilorði fyrir aðgang að skránum var deilt með þér af %$s",
    "Password to access files" : "Lykilorð fyrir aðgang að skrám",
    "%s shared multiple files with \"%s\"." : "%s deildi mörgum skrám með \"%s\".",
    "%s shared multiple files with you." : "%s deildi mörgum skrám með þér.",
    "Boot up" : "Ræsing",
    "Nextcloud Initialization" : "Frumstilling Nextcloud",
    "Circles App Initialization" : "Frumstilling Circles forrits",
    "Fresh installation status" : "Staða ferskrar uppsetningar",
    "Building Local Database" : "Byggi staðværan gagnagrunn",
    "Testing Basic Circle Creation" : "Prófa einfalda gerð hrings",
    "Adding local users and moderators" : "Bæti við notendum og umsjónarmönnum",
    "Show all teams" : "Sýna öll teymi",
    "Create a new team" : "Búa til nýtt teymi",
    "Files" : "Skráaforrit",
    "This feature is not available for personal circles" : "Þessi eiginleiki er ekki tiltækur fyrir persónulega hringi",
    "The team is not federated" : "Teymið er ekki í skýjasambandi",
    "You cannot join this team" : "Þú getur ekki tekið þátt í þessu teymi",
    "This member is not a moderator" : "Þessi meðlimur er ekki umsjónarmaður",
    "Insufficient privileges" : "Ekki næg réttindi",
    "This member does not exist" : "Þessi meðlimur er ekki til",
    "This member is the owner of the team" : "Þessi meðlimur er eigandi teymisins",
    "Level cannot be changed for this type of member" : "Ekki er hægt að breyta stigi fyrir þessa gerð meðlims",
    "You are already a member of this circle" : "Þú ert nú þegar meðlimur í þessum hring",
    "You have been blocked from this circle" : "Þú hefur verið útilokaður frá þessum hring",
    "The account is already a member of this circle" : "Notandaaðgangurinn er nú þegar meðlimur í þessum hring",
    "The account has already been invited into this circle" : "Notandaaðgangnum hefur þegar verið boðið að taka þátt í þessum hring",
    "%s (Team owned by %s)" : "%s (Teymi í eigu notandans %s)",
    "You are now a member of the Team \"%2$s\"" : "Þú ert núna meðlimur í teyminu \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s bauð þér að ganga í teymið \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendi beiðni um að taka þátt í teyminu \"%2$s\"",
    "Accept" : "Samþykkja",
    "Refuse" : "Neita",
    "Leave the team" : "Yfirgefa teymið",
    "%s" : "%s",
    "Personal team" : "Persónulegt teymi",
    "%s owned by %s" : "%s í eigu notandans %s",
    "You have no permission to create a new team" : "Þú hefur ekki leyfi til að búa til nýtt teymi",
    "%s shared a file with \"%s\"." : "%s deildi skrá með \"%s\".",
    "%s shared a file with you." : "%s deildi skrá með þér",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s deildi einhverju efni með þér.\nÞú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s deildi einhverju efni með þér. Þú ættir að hafa fengið sérstakan tölvupóst með tengli sem vísar á gögnin.\n",
    "Password to access content shared with you by %1$s" : "Lykilorði fyrir aðgang að efni var deilt með þér af %1$s",
    "Password to access content" : "Lykilorð fyrir aðgang að efni",
    "This item is already shared with this team" : "Þessu atriði er þegar deilt með þessu teymi",
    "Bring cloud-users closer together." : "Færir notendur tölvuskýja nær hver öðrum.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teymi/Teams gerir fólki kleift að búa til sína eigin hópa af fólki/samstarfsaðilum/vinum.\nÞessa hópa (eða \"hringi\") má síðan nota í deilingaskyni af allskyns öðrum forritum.",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar færslur fundust í þessari möppu",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "Teams' files" : "Skrár teymisins",
    "Select team to filter by" : "Veldu teymi til að sía eftir",
    "No teams found" : "Engin teymi fundust",
    "Please select teams to filter by" : "Veldu teymi til að sía eftir",
    "No files found for the selected teams" : "Engar skrár fundust fyrir valin teymi",
    "Shared to Circles" : "Deilt til hringja"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
